/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.vew.bmvew.bmvew.regel;

import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Modelliert einen Thread, dessen Ausfhrung in Abhngigkeit 
 * von einem oder mehreren Vorgnger-Threads erfolgen kann 
 *
 * @version $Revision: 1.1 $ / $Date: 2009/09/24 12:50:46 $ / ($Author: Pittner $)
 *
 * @author Dambach-Werke GmbH
 * @author Stefan Sans
 */
class WarteThread extends Thread 

{

  private final static Debug _debug = Debug.getLogger();
  
  private String name;
  
  /**
   * Erzeugt einen neuen Warte-Thread
   *
   */  
  public WarteThread(String name)
  {
    super();
    this.name = name;
    _result = true;
  }
  
  /**
   * Das Ergebnis der Ausfhrung dieses Threads
   */
  private boolean _result;
  
  /**
   * Bestimmt das Ergebnis der Ausfhrung dieses Threads
   * @return das Ergebnis der Ausfhrung dieses Threads
   */
  public boolean getResult()
  {
    return _result;
  }
  
  /**
   * Setzt das Ergebnis der Ausfhrung dieses Threads
   * @param result das Ergebnis der Ausfhrung dieses Threads
   */
  void setResult(boolean result)
  {
    _result = result;
  }
  
  /**
   * Startet diesen Wartethread. Der Thread startet nur, wenn alle 
   * Vorgnger-Threads beendet sind und ein positives Ergebnis 
   * geliefert haben
   * @param vorgaenger Feld der Vorgnger-Warte-Threads 
   * - wenn dieses Feld leer ist, startet diese Instanz sofort
   */
  public void start(WarteThread[] vorgaenger) 
  {
    for(Thread thread: vorgaenger)
    {
      try
      {
        thread.join();
      }  
      catch(InterruptedException e)
      {
        _debug.error("WarteThread konnnte nicht gestartet werden: " + name);
      }
    }  
    
    for(WarteThread thread: vorgaenger)
    {
      if (!thread.getResult())
      {
        setResult(false);
        break;
      }  
    }  

    if (_result)
    {
      super.start();  
    }
  }

  /* (non-Javadoc)
   * @see java.lang.Thread#run()
   */
  public void run() 
  {
    // Default Implementierung: Tue nichts
  }

  public String getWarteThreadName()
  {
    return name;
  }

  public void setWarteThreadName(String name)
  {
    this.name = name;
  }
   
}
